@@ -45,11 +45,11 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import (
-    ProjectSortByType,
-    ReportCodeCoverageSortByType,
-    ReportGroupSortByType,
-    SharedResourceSortByType,
-    SortOrderType,
+    ProjectSortByTypeType,
+    ReportCodeCoverageSortByTypeType,
+    ReportGroupSortByTypeType,
+    SharedResourceSortByTypeType,
+    SortOrderTypeType,
 )
 from .type_defs import (
     BuildBatchFilterTypeDef,
@@ -88,27 +88,27 @@ __all__ = (
 
 class DescribeCodeCoveragesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)[Show boto3-stubs documentation](./paginators.md#describecodecoveragespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)[Show boto3-stubs documentation](./paginators.md#describecodecoveragespaginator)
     """
 
     def paginate(
         self,
         reportArn: str,
-        sortOrder: SortOrderType = None,
-        sortBy: ReportCodeCoverageSortByType = None,
+        sortOrder: SortOrderTypeType = None,
+        sortBy: ReportCodeCoverageSortByTypeType = None,
         minLineCoveragePercentage: float = None,
         maxLineCoveragePercentage: float = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeCodeCoveragesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
         [Show boto3-stubs documentation](./paginators.md#describecodecoveragespaginator)
         """
 
 
 class DescribeTestCasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)[Show boto3-stubs documentation](./paginators.md#describetestcasespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)[Show boto3-stubs documentation](./paginators.md#describetestcasespaginator)
     """
 
     def paginate(
@@ -118,175 +118,175 @@ class DescribeTestCasesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeTestCasesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
         [Show boto3-stubs documentation](./paginators.md#describetestcasespaginator)
         """
 
 
 class ListBuildBatchesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)[Show boto3-stubs documentation](./paginators.md#listbuildbatchespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)[Show boto3-stubs documentation](./paginators.md#listbuildbatchespaginator)
     """
 
     def paginate(
         self,
         filter: BuildBatchFilterTypeDef = None,
-        sortOrder: SortOrderType = None,
+        sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBuildBatchesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
         [Show boto3-stubs documentation](./paginators.md#listbuildbatchespaginator)
         """
 
 
 class ListBuildBatchesForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)[Show boto3-stubs documentation](./paginators.md#listbuildbatchesforprojectpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)[Show boto3-stubs documentation](./paginators.md#listbuildbatchesforprojectpaginator)
     """
 
     def paginate(
         self,
         projectName: str = None,
         filter: BuildBatchFilterTypeDef = None,
-        sortOrder: SortOrderType = None,
+        sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBuildBatchesForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
         [Show boto3-stubs documentation](./paginators.md#listbuildbatchesforprojectpaginator)
         """
 
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)[Show boto3-stubs documentation](./paginators.md#listbuildspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)[Show boto3-stubs documentation](./paginators.md#listbuildspaginator)
     """
 
     def paginate(
-        self, sortOrder: SortOrderType = None, PaginationConfig: PaginatorConfigTypeDef = None
+        self, sortOrder: SortOrderTypeType = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListBuildsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         [Show boto3-stubs documentation](./paginators.md#listbuildspaginator)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)[Show boto3-stubs documentation](./paginators.md#listbuildsforprojectpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)[Show boto3-stubs documentation](./paginators.md#listbuildsforprojectpaginator)
     """
 
     def paginate(
         self,
         projectName: str,
-        sortOrder: SortOrderType = None,
+        sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListBuildsForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         [Show boto3-stubs documentation](./paginators.md#listbuildsforprojectpaginator)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)[Show boto3-stubs documentation](./paginators.md#listprojectspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)[Show boto3-stubs documentation](./paginators.md#listprojectspaginator)
     """
 
     def paginate(
         self,
-        sortBy: ProjectSortByType = None,
-        sortOrder: SortOrderType = None,
+        sortBy: ProjectSortByTypeType = None,
+        sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](./paginators.md#listprojectspaginator)
         """
 
 
 class ListReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)[Show boto3-stubs documentation](./paginators.md#listreportgroupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)[Show boto3-stubs documentation](./paginators.md#listreportgroupspaginator)
     """
 
     def paginate(
         self,
-        sortOrder: SortOrderType = None,
-        sortBy: ReportGroupSortByType = None,
+        sortOrder: SortOrderTypeType = None,
+        sortBy: ReportGroupSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
         [Show boto3-stubs documentation](./paginators.md#listreportgroupspaginator)
         """
 
 
 class ListReportsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)[Show boto3-stubs documentation](./paginators.md#listreportspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)[Show boto3-stubs documentation](./paginators.md#listreportspaginator)
     """
 
     def paginate(
         self,
-        sortOrder: SortOrderType = None,
+        sortOrder: SortOrderTypeType = None,
         filter: ReportFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
         [Show boto3-stubs documentation](./paginators.md#listreportspaginator)
         """
 
 
 class ListReportsForReportGroupPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)[Show boto3-stubs documentation](./paginators.md#listreportsforreportgrouppaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)[Show boto3-stubs documentation](./paginators.md#listreportsforreportgrouppaginator)
     """
 
     def paginate(
         self,
         reportGroupArn: str,
-        sortOrder: SortOrderType = None,
+        sortOrder: SortOrderTypeType = None,
         filter: ReportFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListReportsForReportGroupOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
         [Show boto3-stubs documentation](./paginators.md#listreportsforreportgrouppaginator)
         """
 
 
 class ListSharedProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)[Show boto3-stubs documentation](./paginators.md#listsharedprojectspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)[Show boto3-stubs documentation](./paginators.md#listsharedprojectspaginator)
     """
 
     def paginate(
         self,
-        sortBy: SharedResourceSortByType = None,
-        sortOrder: SortOrderType = None,
+        sortBy: SharedResourceSortByTypeType = None,
+        sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSharedProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
         [Show boto3-stubs documentation](./paginators.md#listsharedprojectspaginator)
         """
 
 
 class ListSharedReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)[Show boto3-stubs documentation](./paginators.md#listsharedreportgroupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)[Show boto3-stubs documentation](./paginators.md#listsharedreportgroupspaginator)
     """
 
     def paginate(
         self,
-        sortOrder: SortOrderType = None,
-        sortBy: SharedResourceSortByType = None,
+        sortOrder: SortOrderTypeType = None,
+        sortBy: SharedResourceSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSharedReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
         [Show boto3-stubs documentation](./paginators.md#listsharedreportgroupspaginator)
         """
